@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2025 Lukas Spies                                  **
+ ** Copyright (C) 2011-2026 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -19,30 +19,24 @@
  ** along with PhotoQt. If not, see <http://www.gnu.org/licenses/>.      **
  **                                                                      **
  **************************************************************************/
-
-#ifndef PQCLOCATION_H
-#define PQCLOCATION_H
+#pragma once
 
 #include <QObject>
 #include <QSqlDatabase>
 #include <QPointF>
 #include <QVariantMap>
+#include <QQmlEngine>
 
 class QTimer;
 
 class PQCLocation : public QObject {
 
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
 public:
-    static PQCLocation& get() {
-        static PQCLocation instance;
-        return instance;
-    }
-    ~PQCLocation();
-
-    PQCLocation(PQCLocation const&)    = delete;
-    void operator=(PQCLocation const&) = delete;
+    PQCLocation(QObject *parent = nullptr);
 
     Q_INVOKABLE void storeLocation(const QString path, const QPointF gps);
     Q_INVOKABLE void scanForLocations(QStringList files);
@@ -89,9 +83,9 @@ public:
     Q_PROPERTY(QPointF maximumLocation READ getMaximumLocation NOTIFY maximumLocationChanged)
     QPointF getMaximumLocation() { return m_maximumLocation; }
 
-private:
-    PQCLocation(QObject *parent = nullptr);
+    Q_INVOKABLE void closeDatabase();
 
+private:
     QSqlDatabase db;
     bool dbOpened;
     bool dbIsTransaction;
@@ -115,5 +109,3 @@ Q_SIGNALS:
     void maximumLocationChanged();
 
 };
-
-#endif // PQCLOCATION_H
