@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2025 Lukas Spies                                  **
+ ** Copyright (C) 2011-2026 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -19,26 +19,31 @@
  ** along with PhotoQt. If not, see <http://www.gnu.org/licenses/>.      **
  **                                                                      **
  **************************************************************************/
-
-#ifndef PQCMETADATA_H
-#define PQCMETADATA_H
+#pragma once
 
 #include <QObject>
 #include <QtDebug>
-#include <QtQmlIntegration>
+#include <QQmlEngine>
 
 class QTimer;
 
+/*************************************************************/
+/*************************************************************/
+//
+//      NOTE: This singleton CANNOT be used from C++.
+//            It can ONLY be used from QML.
+//
+/*************************************************************/
+/*************************************************************/
+
 class PQCMetaData : public QObject {
 
     Q_OBJECT
+    QML_ELEMENT
     QML_SINGLETON
 
 public:
-    static PQCMetaData& get();
-
-    PQCMetaData(PQCMetaData const&)     = delete;
-    void operator=(PQCMetaData const&) = delete;
+    PQCMetaData(QObject *parent = 0);
 
     Q_PROPERTY(bool validFile READ getValidFile WRITE setValidFile NOTIFY validFileChanged)
     bool getValidFile() { return m_validFile; }
@@ -211,9 +216,11 @@ public:
         }
     }
 
-private:
-    PQCMetaData(QObject *parent = 0);
+    Q_INVOKABLE void forceUpdateMetadata() {
+        updateMetadata();
+    }
 
+private:
     QTimer *loadDelay;
 
     void setEmptyData();
@@ -267,5 +274,3 @@ Q_SIGNALS:
     void iptcCopyrightChanged();
 
 };
-
-#endif // PQCMETADATA_H
