@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2025 Lukas Spies                                  **
+ ** Copyright (C) 2011-2026 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -19,15 +19,19 @@
  ** along with PhotoQt. If not, see <http://www.gnu.org/licenses/>.      **
  **                                                                      **
  **************************************************************************/
-
-#ifndef PQPHOTOSPHERE_H
-#define PQPHOTOSPHERE_H
+#pragma once
 
 // This is the QML type
 
+#ifdef PQMPHOTOSPHERE
 #include <QQuickFramebufferObject>
 
 class PQCPhotoSphere : public QQuickFramebufferObject {
+#else
+#include <QQuickItem>
+
+class PQCPhotoSphere : public QQuickItem {
+#endif
 
     Q_OBJECT
     QML_ELEMENT
@@ -51,6 +55,8 @@ public:
     QString getSource();
     void setSource(QString path);
 
+    Q_PROPERTY(bool isSupported MEMBER m_isSupported NOTIFY isSupportedChanged)
+
     QByteArray getImage();
     bool getPartial();
     QSize getCroppedSize();
@@ -61,11 +67,14 @@ Q_SIGNALS:
     void elevationChanged();
     void fieldOfViewChanged();
     void sourceChanged();
+    void isSupportedChanged();
 
 protected:
+#ifdef PQMPHOTOSPHERE
     QSGNode *updatePaintNode(QSGNode *oldNode, UpdatePaintNodeData *data) override;
     Renderer *createRenderer() const override;
     void updateSphere();
+#endif
 
 private:
     QByteArray image;
@@ -77,9 +86,8 @@ private:
     double m_elevation;
     double m_fieldOfView;
     QString m_imageUrl;
+    bool m_isSupported;
 
     bool recreateRenderer = false;
 
 };
-
-#endif // PQPHOTOSPHERE_H
