@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2025 Lukas Spies                                  **
+ ** Copyright (C) 2011-2026 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -19,35 +19,30 @@
  ** along with PhotoQt. If not, see <http://www.gnu.org/licenses/>.      **
  **                                                                      **
  **************************************************************************/
-
-#ifndef PQCSCRIPTSCLIPBOARD_H
-#define PQCSCRIPTSCLIPBOARD_H
+#pragma once
 
 #include <QObject>
-#include <QtQmlIntegration>
 
 class QClipboard;
 
 class PQCScriptsClipboard : public QObject {
 
     Q_OBJECT
-    QML_SINGLETON
 
 public:
     static PQCScriptsClipboard& get() {
         static PQCScriptsClipboard instance;
         return instance;
     }
-    ~PQCScriptsClipboard();
 
-    PQCScriptsClipboard(PQCScriptsClipboard const&)     = delete;
+    PQCScriptsClipboard(PQCScriptsClipboard const&) = delete;
     void operator=(PQCScriptsClipboard const&) = delete;
 
-    Q_INVOKABLE bool areFilesInClipboard();
-    Q_INVOKABLE void copyFilesToClipboard(QStringList files);
-    Q_INVOKABLE QStringList getListOfFilesInClipboard();
-    Q_INVOKABLE void copyTextToClipboard(QString txt, bool removeHTML= false);
-    Q_INVOKABLE QString getTextFromClipboard();
+    bool areFilesInClipboard();
+    void copyFilesToClipboard(QStringList files);
+    QStringList getListOfFilesInClipboard();
+    void copyTextToClipboard(QString txt, bool removeHTML= false);
+    QString getTextFromClipboard();
 
 private:
     PQCScriptsClipboard();
@@ -58,5 +53,3 @@ Q_SIGNALS:
     void clipboardUpdated();
 
 };
-
-#endif
