@@ -51,7 +51,7 @@ public:
     bool isMpvVideo(QString path);
     bool isQtVideo(QString path);
     bool isPDFDocument(QString path);
-    bool isArchive(QString path);
+    bool isArchive(QString path, bool silent = false);
     int isMotionPhoto(QString path);
     bool isPhotoSphere(QString path);
     bool isComicBook(QString path);
@@ -63,7 +63,7 @@ public:
     bool isItAnimated(QString filename);
     bool supportsTransparency(QString path);
     void setSupportsTransparency(QString path, bool alpha);
-    double getPixelDensity();
+    double getPixelDensity(QString modelName);
     QString getNameFromMimetype(QString mimetype, QString filename);
     QString getMimetypeForFile(QString path);
 
@@ -75,8 +75,8 @@ public:
     void applyExifOrientation(const QString filename, QImage &img);
 
     // archive/document methods
-    void listArchiveContent(QString path, bool insideFilenameOnly = false);
-    QStringList listArchiveContentWithoutThread(QString path, QString cacheKey = "", bool insideFilenameOnly = false);
+    void listArchiveContent(QString path);
+    QStringList listArchiveContentWithoutThread(QString path, QString cacheKey = "");
     int getNumberDocumentPages(QString path);
     int getDocumentPageCount(QString path);
     QString extractArchiveFileToTempLocation(QString path);
@@ -98,9 +98,11 @@ private:
     mutable QMutex alphaMutex;
     QMap<QString, bool> alphaChannels;
 
-    double devicePixelRatioCached;
+    QVariantMap devicePixelRatioCached;
     qint64 devicePixelRatioCachedWhen;
 
+    QStringList inProcesOfLoadingTheseArchives;
+
 
 Q_SIGNALS:
     void haveArchiveContentFor(QString filename, QStringList content);
