@@ -79,10 +79,6 @@
 #include <exiv2/exiv2.hpp>
 #endif
 
-#ifdef PQMFREEIMAGE
-#include <FreeImage.h>
-#endif
-
 #ifdef Q_OS_WIN
 #include <QQuickWindow>
 #include <QSGRendererInterface>
@@ -137,7 +133,7 @@ int main(int argc, char **argv) {
         newdir.mkdir(portablefolder);
     }
 #else
-    QString portablefolder = QString("%1/.PhotoQtData").arg(argc > 1 ? argv[1] : QCoreApplication::applicationDirPath());
+    QString portablefolder = QString("%1/PhotoQtData").arg(argc > 1 ? argv[1] : QCoreApplication::applicationDirPath());
     QDir dir;
     dir.mkdir(portablefolder);
 #endif
@@ -230,10 +226,8 @@ int main(int argc, char **argv) {
     /***************************************/
     // figure out modern vs integrated without use of PQCSettings
 
-    bool useModernInterface = (startupHandler.getInterfaceVariant()=="modern");
-
     if(app.forceModernInterface || app.forceIntegratedInterface) {
-        useModernInterface = !app.forceIntegratedInterface;
+        bool useModernInterface = !app.forceIntegratedInterface;
         QSqlDatabase dbtmp = QSqlDatabase::database("settings");
         QSqlQuery query(dbtmp);
         query.prepare("INSERT OR REPLACE INTO `general` (`name`,`value`,`datatype`) VALUES ('InterfaceVariant', :val, 'string')");
@@ -274,10 +268,6 @@ int main(int argc, char **argv) {
     ilInit();
 #endif
 
-#ifdef PQMFREEIMAGE
-    FreeImage_Initialise();
-#endif
-
 #ifdef PQMLIBVIPS
     VIPS_INIT(argv[0]);
 #endif
@@ -316,10 +306,6 @@ int main(int argc, char **argv) {
 
     int currentExitCode = app.exec();
 
-#ifdef PQMFREEIMAGE
-    FreeImage_DeInitialise();
-#endif
-
 #ifdef PQMLIBVIPS
     vips_shutdown();
 #endif
