@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2025 Lukas Spies                                  **
+ ** Copyright (C) 2011-2026 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -24,29 +24,30 @@
 #include <QFileInfo>
 #include <QtSql/QSqlError>
 #include <QtSql/QSqlQuery>
-#include <QCoreApplication>
+#include <QApplication>
 #include <pqc_shortcuts.h>
 #include <pqc_configfiles.h>
-#include <pqc_notify.h>
+#include <pqc_notify_cpp.h>
 
 PQCShortcuts::PQCShortcuts() {
 
     // connect to database
-    if(QSqlDatabase::isDriverAvailable("QSQLITE3"))
-        db = QSqlDatabase::addDatabase("QSQLITE3", "shortcuts");
-    else if(QSqlDatabase::isDriverAvailable("QSQLITE"))
-        db = QSqlDatabase::addDatabase("QSQLITE", "shortcuts");
-    db.setDatabaseName(PQCConfigFiles::get().SHORTCUTS_DB());
+    db = QSqlDatabase::database("shortcuts");
 
     readonly = false;
 
     QFileInfo infodb(PQCConfigFiles::get().SHORTCUTS_DB());
 
-    if(!infodb.exists() || !db.open()) {
+    if(!db.open()) {
 
         qCritical() << "ERROR opening database:" << db.lastError().text();
         qCritical() << "Will load read-only database of default shortcuts";
 
+        if(QSqlDatabase::isDriverAvailable("QSQLITE3"))
+            db = QSqlDatabase::addDatabase("QSQLITE3", "defaultshortcuts");
+        else if(QSqlDatabase::isDriverAvailable("QSQLITE"))
+            db = QSqlDatabase::addDatabase("QSQLITE", "defaultshortcuts");
+
         readonly = true;
         db.setConnectOptions("QSQLITE_OPEN_READONLY");
 
@@ -58,8 +59,8 @@ PQCShortcuts::PQCShortcuts() {
         if(!QFile::copy(":/shortcuts.db", tmppath)) {
             qCritical() << "ERROR copying read-only default database!";
             //: This is the window title of an error message box
-            QMessageBox::critical(0, QCoreApplication::translate("PQShortcuts", "ERROR getting database with default shortcuts"),
-                                     QCoreApplication::translate("PQShortcuts", "I tried hard, but I just cannot open even a read-only version of the shortcuts database.") + QCoreApplication::translate("PQShortcuts", "Something went terribly wrong somewhere!"));
+            QMessageBox::critical(0, QApplication::translate("PQShortcuts", "ERROR getting database with default shortcuts"),
+                                     QApplication::translate("PQShortcuts", "I tried hard, but I just cannot open even a read-only version of the shortcuts database.") + QApplication::translate("PQShortcuts", "Something went terribly wrong somewhere!"));
             return;
         }
 
@@ -70,8 +71,8 @@ PQCShortcuts::PQCShortcuts() {
 
         if(!db.open()) {
             qCritical() << "ERROR opening read-only default database!";
-            QMessageBox::critical(0, QCoreApplication::translate("PQShortcuts", "ERROR opening database with default settings"),
-                                     QCoreApplication::translate("PQShortcuts", "I tried hard, but I just cannot open the database of default shortcuts.") + QCoreApplication::translate("PQShortcuts", "Something went terribly wrong somewhere!"));
+            QMessageBox::critical(0, QApplication::translate("PQShortcuts", "ERROR opening database with default settings"),
+                                     QApplication::translate("PQShortcuts", "I tried hard, but I just cannot open the database of default shortcuts.") + QApplication::translate("PQShortcuts", "Something went terribly wrong somewhere!"));
             return;
         }
 
@@ -83,8 +84,6 @@ PQCShortcuts::PQCShortcuts() {
 
     }
 
-    readDB();
-
     dbCommitTimer = new QTimer();
     dbCommitTimer->setSingleShot(true);
     dbCommitTimer->setInterval(400);
@@ -95,11 +94,15 @@ PQCShortcuts::PQCShortcuts() {
             qCritical() << "ERROR committing database:" << db.lastError().text();
     });
 
-    connect(&PQCNotify::get(), &PQCNotify::resetShortcutsToDefault, this, &PQCShortcuts::resetToDefault);
+    readDB();
 
 }
 
-PQCShortcuts::~PQCShortcuts() {}
+PQCShortcuts::~PQCShortcuts() {
+    if(dbCommitTimer != nullptr) {
+        delete dbCommitTimer;
+    }
+}
 
 bool PQCShortcuts::backupDatabase() {
 
@@ -230,6 +233,7 @@ void PQCShortcuts::readDB() {
     qDebug() << "";
 
     shortcuts.clear();
+    m_commands.clear();
     shortcutsOrder.clear();
 
     QSqlQuery query(db);
@@ -251,6 +255,13 @@ void PQCShortcuts::readDB() {
 
         if(combo == "Del") combo = "Delete";
 
+        for(const QString &c : commands) {
+            if(m_commands.contains(c))
+                m_commands[c].append(combo);
+            else
+                m_commands.insert(c, QVariantList() << combo);
+        }
+
         shortcuts[combo] = QVariantList() << commands << cycle << cycletimeout << simultaneous;
         shortcutsOrder.push_back(combo);
 
@@ -411,223 +422,367 @@ void PQCShortcuts::resetCommandCycle(QString combo) {
     commandCycle.remove(combo);
 }
 
-bool PQCShortcuts::migrate(QString oldversion) {
+QVariantList PQCShortcuts::getShortcutsForCommand(QString cmd) {
+    return m_commands[cmd];
+}
 
-    qDebug() << "args: oldversion =" << oldversion;
+int PQCShortcuts::getNumberInternalCommandsForShortcut(QString combo) {
 
-    /*************************************************************************/
-    /**************************** IMPORTANT NOTE *****************************/
-    /*************************************************************************/
-    //                                                                       //
-    // BEFORE EVERY NEW RELEASE THE NEW VERSION NUMBER HAS TO BE ADDED BELOW //
-    //                                                                       //
-    // and the same needs to be done in pqc_settings.cpp:migrate()           //
-    /*************************************************************************/
+    int num = 0;
 
-    QStringList versions;
-    versions << "4.0" << "4.1" << "4.2" << "4.3" << "4.4" << "4.5" << "4.6" << "4.7" << "4.8" << "4.8.1";
-    // when removing the 'dev' value, check below for any if statement involving 'dev'!
+    const QList<QVariant> lst = shortcuts.value(combo).toList();
+    if(lst.length() == 0)
+        return num;
 
-    // this is a safety check to make sure we don't forget the above check
-    if(oldversion != "dev" && versions.indexOf(oldversion) == -1) {
-        qCritical() << "WARNING: The current version number needs to be added to the migrate() functions";
+    for(const QString &c : lst.toList()[0].toStringList()) {
+        if(c.startsWith("__"))
+            num += 1;
+    }
+    return num;
+}
+
+int PQCShortcuts::getNumberExternalCommandsForShortcut(QString combo) {
+
+    int num = 0;
+
+    const QList<QVariant> lst = shortcuts.value(combo).toList();
+    if(lst.length() == 0)
+        return num;
+
+    for(const QString &c : lst[0].toStringList()) {
+        if(!c.startsWith("__"))
+            num += 1;
     }
 
-    int iVersion = 0;
-    if(oldversion == "dev")
-        iVersion = versions.length()-1;
-    else if(oldversion != "" && versions.contains(oldversion))
-        // we do a +1 as we are on the found version and don't need to migrate to it
-        iVersion = versions.indexOf(oldversion)+1;
+    return num;
 
-    // we iterate through all migrations one by one
+}
 
-    dbCommitTimer->stop();
+void PQCShortcuts::saveInternalShortcutCombos(const QVariantList lst) {
+
+    qDebug() << "args: lst";
+
+    QMap<QString, QStringList> map;
+
+    // first we need to create a map of: combo => all commands
+    for(const QVariant &entry : lst) {
+
+        QVariantList l = entry.toList();
+        const QString cmd = l[0].toString();
+        const QVariantList combos = l[1].toList();
+
+        for(const QVariant &c : combos) {
+            if(map.contains(c.toString()))
+                map[c.toString()].append(cmd);
+            else
+                map.insert(c.toString(), (QStringList() << cmd));
+        }
 
-    if(dbIsTransaction) {
-        db.commit();
-        dbIsTransaction = false;
-        if(db.lastError().text().trimmed().length())
-            qWarning() << "ERROR committing database:" << db.lastError().text();
     }
 
-    for(int iV = iVersion; iV < versions.length(); ++iV) {
+    QMap<QString, QVariantList> new_shortcuts;
 
-        QString curVer = versions[iV];
+    // then we step through the new map and match it up with the existing map to add in any external shortcuts and to preserve any potentially set order
 
-        /*******************************************/
-        /*******************************************/
-        // update to v4.0
+    QMapIterator<QString, QStringList> iter(map);
+    while(iter.hasNext()) {
 
-        if(curVer == "4.0") {
+        iter.next();
 
-            // make sure new table name exists and if not create it and populate it with default data
+        QString combo = iter.key();
+        QStringList cmds = iter.value();
 
-            QSqlQuery query(db);
+        // case 1: shortcut exists in old map
+        if(shortcuts.contains(combo)) {
 
-            query.exec("SELECT COUNT(name) FROM sqlite_master WHERE type='table' AND name='shortcuts'");
-            if(query.lastError().text().trimmed().length()) {
-                qWarning() << "Unable to check if shortcuts table exists already:" << query.lastError().text();
-                continue;
-            }
-            query.next();
+            QStringList oldcmds = shortcuts[combo][0].toStringList();
 
-            // table does not exist yet
-            if(query.value(0).toInt() == 0) {
+            // case a: commands are unchanged
+            if(oldcmds == cmds) {
 
-                QSqlQuery queryCreate(db);
-                queryCreate.exec("CREATE TABLE 'shortcuts' ('combo' TEXT UNIQUE, 'commands' TEXT, 'cycle' INTEGER, 'cycletimeout' INTEGER, 'simultaneous' INTEGER)");
-                queryCreate.clear();
+                new_shortcuts.insert(combo, QVariantList() << cmds << shortcuts[combo][1] << shortcuts[combo][2] << shortcuts[combo][3]);
 
-                if(!QFile::copy(":/shortcuts.db", PQCConfigFiles::get().CACHE_DIR() + "/shortcutstmp.db")) {
-                    qWarning() << "Unable to create shortcuts database";
-                    continue;
+            // case b: commands are changed
+            } else {
+
+                QStringList newcmds;
+
+                // first we copy over (in the old order) any commands that remained unchanged
+                // we include external commands as these are manipulated in a different place
+                for(const QString &c : oldcmds) {
+                    if(cmds.contains(c) || !c.startsWith("__"))
+                        newcmds.append(c);
                 }
 
-                QFile file(PQCConfigFiles::get().CACHE_DIR() + "/shortcutstmp.db");
-                file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
-
-                QSqlQuery queryAttach(db);
-                queryAttach.exec(QString("ATTACH DATABASE '%1' AS defaultdb").arg(PQCConfigFiles::get().CACHE_DIR() + "/shortcutstmp.db"));
-                if(queryAttach.lastError().text().trimmed().length()) {
-                    qWarning() << "Unable to attach default database:" << queryAttach.lastError().text();
-                    continue;
+                // then we add at the end any new commands
+                for(const QString &c : cmds) {
+                    if(!newcmds.contains(c))
+                        newcmds.append(c);
                 }
 
-                QSqlQuery queryInsert(db);
-                queryInsert.exec("INSERT INTO shortcuts SELECT * FROM defaultdb.shortcuts;");
-                if(queryInsert.lastError().text().trimmed().length()) {
-                    qWarning() << "Failed to insert default shortcuts:" << queryInsert.lastError().text();
-                }
-                queryInsert.clear();
-
-                queryAttach.clear();
+                new_shortcuts.insert(combo, QVariantList() << newcmds << shortcuts[combo][1] << shortcuts[combo][2] << shortcuts[combo][3]);
 
             }
 
-            query.clear();
+        // case 2: shortcut does not exist in old map
+        } else {
 
-        } else if(curVer == "4.4") {
+            new_shortcuts.insert(combo, QVariantList() << cmds << 1 << 0 << 0);
 
-            // Update 'Del' to 'Delete'
+        }
 
-            // first update shortcut set to exactly 'Del'
-            QSqlQuery query(db);
-            if(!query.exec("Update `shortcuts` SET `combo`='Delete' WHERE `combo`='Del'"))
-                qWarning() << "Unable to change 'Del' shortcut to 'Delete':" << query.lastError().text();
-            query.clear();
+    }
 
-            // next we update the ones with 'Del' no at the end
-            QSqlQuery query2(db);
-            if(query2.exec("SELECT `combo` FROM `shortcuts` WHERE combo LIKE 'Del+%'")) {
+    // then we step through the original map and check all the combos not in the new map yet that have external shortcuts set
+    // (these would not show up in the passed-on list but need to be preserved)
 
-                while(query2.next()) {
+    QMapIterator<QString, QVariantList> iterExt(shortcuts);
+    while(iterExt.hasNext()) {
 
-                    QString combo = query2.value(0).toString();
-                    QString comboNEW = query2.value(0).toString().replace("Del+", "Delete+");
+        iterExt.next();
 
-                    QSqlQuery queryUpd(db);
-                    queryUpd.prepare("UPDATE `shortcuts` SET `combo`=:combonew WHERE `combo`=:combo");
-                    queryUpd.bindValue(":combonew", comboNEW);
-                    queryUpd.bindValue(":combo", combo);
-                    if(!queryUpd.exec())
-                        qWarning() << "Unable to update 'Del' to 'Delete' in shortcut" << combo << "::" << queryUpd.lastError().text();
-                    queryUpd.clear();
+        QString combo = iterExt.key();
+
+        // combo not in new map
+        if(!new_shortcuts.contains(combo)) {
+
+            QStringList oldcmds = shortcuts[combo][0].toStringList();
+
+            for(const QString &c : oldcmds) {
+
+                if(!c.startsWith("__")) {
+
+                    if(new_shortcuts.contains(combo)) {
+
+                        QStringList oldcombos = new_shortcuts.value(combo)[0].toStringList();
+                        oldcombos.append(c);
+                        new_shortcuts.insert(combo, QVariantList() << oldcombos << shortcuts[combo][1] << shortcuts[combo][2] << shortcuts[combo][3]);
+
+                    } else {
+
+                        new_shortcuts.insert(combo, QVariantList() << (QStringList() << c) << shortcuts[combo][1] << shortcuts[combo][2] << shortcuts[combo][3]);
+
+                    }
 
                 }
 
             }
 
-            query2.clear();
-
-            // next we update the ones with 'Del' at the end
-            if(query.exec("SELECT `combo` FROM `shortcuts` WHERE combo LIKE '%+Del'")) {
-
-                while(query.next()) {
-
-                    QString combo = query.value(0).toString();
-                    QString comboNEW = combo.replace("+Del", "+Delete");
-
-                    QSqlQuery queryUpd(db);
-                    queryUpd.prepare("UPDATE `shortcuts` SET `combo`=:combonew WHERE `combo`=:combo");
-                    queryUpd.bindValue(":combonew", comboNEW);
-                    queryUpd.bindValue(":combo", combo);
-                    queryUpd.exec();
-                    if(queryUpd.lastError().text().trimmed().length())
-                        qWarning() << "Unable to update 'Del' to 'Delete' in shortcut" << combo << "::" << queryUpd.lastError().text();
-                    queryUpd.clear();
-
-                }
-
-            }
-
-            query.clear();
-
-        } else if(curVer == "4.6") {
-
-            // Ctrl+Z is to be added for __undoTrash. If Ctrl+Z is already used, we need to fix this
-
-            QSqlQuery query(db);
-
-            query.exec("SELECT `combo` FROM `shortcuts` WHERE `combo` LIKE '%Ctrl%Z' AND `commands` NOT LIKE '%__undoTrash%'");
-            if(query.lastError().text().trimmed().length()) {
-                qWarning() << "Unable to query for shortcuts with Ctrl+Z:" << query.lastError().text();
-                continue;
-            }
-
-            bool CtrlZ = true;
-            bool CtrlShiftZ = true;
-            bool CtrlAltShiftZ = true;
-
-            while(query.next()) {
-
-                QString combo = query.value(0).toString();
-
-                if(combo == "Ctrl+Z")
-                    CtrlZ = false;
-                else if(combo == "Ctrl+Shift+Z")
-                    CtrlShiftZ = false;
-                else if(combo == "Ctrl+Alt+Shift+Z")
-                    CtrlAltShiftZ = false;
-
-            }
-
-            query.clear();
-
-            QString newcombo = "";
-            if(CtrlZ)
-                newcombo = "Ctrl+Z";
-            else if(CtrlShiftZ)
-                newcombo = "Ctrl+Shift+Z";
-            else if(CtrlAltShiftZ)
-                newcombo = "Ctrl+Alt+Shift+Z";
-
-            if(newcombo != "") {
-
-                QSqlQuery queryNew(db);
-
-                queryNew.prepare("INSERT INTO shortcuts (`combo`,`commands`,`cycle`,`cycletimeout`,`simultaneous`) VALUES(:com,'__undoTrash',1,0,0)");
-                queryNew.bindValue(":com", newcombo);
-                if(!queryNew.exec())
-                    qWarning() << "Unable to insert __undoTrash shortcut";
-
-                queryNew.clear();
-
-            }
-
         }
 
     }
 
-    readDB();
+    /**************************************************/
 
-    return true;
+    // now we can write this new map to the database
+
+    writeNewShortcutsMapToDatabaseAndRead(new_shortcuts);
+
+}
+
+void PQCShortcuts::saveExternalShortcutCombos(const QVariantList lst) {
+
+    qDebug() << "args: lst";
+
+    QMap<QString, QStringList> map;
+
+    // first we need to create a map of: combo => all commands
+    for(const QVariant &entry : lst) {
+
+        QVariantList l = entry.toList();
+        const QStringList combos = l[0].toStringList();
+        const QString exec = l[1].toString();
+        const QString flags = l[2].toString();
+        const int quit = l[3].toInt();
+
+        QString cmd = QString("%1:/:/:%2:/:/:%3").arg(exec, flags).arg(quit);
+
+        for(const QVariant &c : combos) {
+            if(map.contains(c.toString()))
+                map[c.toString()].append(cmd);
+            else
+                map.insert(c.toString(), (QStringList() << cmd));
+        }
+
+    }
+
+    QMap<QString, QVariantList> new_shortcuts;
+
+    // then we step through the new map and match it up with the existing map to add in any internal shortcuts and to preserve any potentially set order
+
+    QMapIterator<QString, QStringList> iter(map);
+    while(iter.hasNext()) {
+
+        iter.next();
+
+        QString combo = iter.key();
+        QStringList cmds = iter.value();
+
+        // case 1: shortcut exists in old map
+        if(shortcuts.contains(combo)) {
+
+            QStringList oldcmds = shortcuts[combo][0].toStringList();
+
+            // case a: commands are unchanged
+            if(oldcmds == cmds) {
+
+                new_shortcuts.insert(combo, QVariantList() << cmds << shortcuts[combo][1] << shortcuts[combo][2] << shortcuts[combo][3]);
+
+            // case b: commands are changed
+            } else {
+
+                QStringList newcmds;
+
+                // first we copy over (in the old order) any commands that remained unchanged
+                // we include external commands as these are manipulated in a different place
+                for(const QString &c : oldcmds) {
+                    if(cmds.contains(c) || c.startsWith("__"))
+                        newcmds.append(c);
+                }
+
+                // then we add at the end any new commands
+                for(const QString &c : cmds) {
+                    if(!newcmds.contains(c))
+                        newcmds.append(c);
+                }
+
+                new_shortcuts.insert(combo, QVariantList() << newcmds << shortcuts[combo][1] << shortcuts[combo][2] << shortcuts[combo][3]);
+
+            }
+
+            // case 2: shortcut does not exist in old map
+        } else {
+
+            new_shortcuts.insert(combo, QVariantList() << cmds << 1 << 0 << 0);
+
+        }
+
+    }
+
+    // then we step through the original map and check all the combos not in the new map yet that have internal shortcuts set
+    // (these would not show up in the passed-on list but need to be preserved)
+
+    QMapIterator<QString, QVariantList> iterInt(shortcuts);
+    while(iterInt.hasNext()) {
+
+        iterInt.next();
+
+        QString combo = iterInt.key();
+
+        // combo not in new map
+        if(!new_shortcuts.contains(combo)) {
+
+            QStringList oldcmds = shortcuts[combo][0].toStringList();
+
+            for(const QString &c : oldcmds) {
+
+                if(c.startsWith("__")) {
+
+                    if(new_shortcuts.contains(combo)) {
+
+                        QStringList oldcombos = new_shortcuts.value(combo)[0].toStringList();
+                        oldcombos.append(c);
+                        new_shortcuts.insert(combo, QVariantList() << oldcombos << shortcuts[combo][1] << shortcuts[combo][2] << shortcuts[combo][3]);
+
+                    } else {
+
+                        new_shortcuts.insert(combo, QVariantList() << (QStringList() << c) << shortcuts[combo][1] << shortcuts[combo][2] << shortcuts[combo][3]);
+
+                    }
+
+                }
+
+            }
+
+        }
+
+    }
+
+    /**************************************************/
+
+    // now we can write this new map to the database
+
+    writeNewShortcutsMapToDatabaseAndRead(new_shortcuts);
+
+}
+
+void PQCShortcuts::saveDuplicateShortcutsCommandOrder(const QVariantList lst) {
+
+    qDebug() << "args: lst";
+
+    QMap<QString, QVariantList> new_shortcuts = shortcuts;
+
+    for(const QVariant &entry : lst) {
+
+        QVariantList dat = entry.toList();
+
+        const QString combo = dat[0].toString();
+        const QStringList cmds = dat[1].toStringList();
+        const int cycle = dat[2].toInt();
+        const int cycletimeout = dat[3].toInt();
+
+        new_shortcuts.insert(combo, QVariantList() << cmds << cycle << cycletimeout << (cycle==1 ? 0 : 1));
+
+    }
+
+    writeNewShortcutsMapToDatabaseAndRead(new_shortcuts);
+
+}
+
+void PQCShortcuts::writeNewShortcutsMapToDatabaseAndRead(QMap<QString, QVariantList> newmap) {
+
+    // remove old shortcuts
+    QSqlQuery query(db);
+    if(!query.exec("DELETE FROM 'shortcuts'")) {
+        qWarning() << "SQL error:" << query.lastError().text();
+        return;
+    }
+    query.clear();
+
+    QMapIterator<QString, QVariantList> iterEnter(newmap);
+
+    while(iterEnter.hasNext()) {
+
+        iterEnter.next();
+
+        const QString combo = iterEnter.key();
+        const QStringList cmds = iterEnter.value()[0].toStringList();
+        const int cycle = iterEnter.value()[1].toInt();
+        const int cycletimeout = iterEnter.value()[2].toInt();
+        const int simultaneous = iterEnter.value()[3].toInt();
+
+        QSqlQuery query(db);
+
+        query.prepare("INSERT OR REPLACE INTO 'shortcuts' (`combo`,`commands`,`cycle`,`cycletimeout`,`simultaneous`) VALUES (:combo, :cmds, :cycle, :cycletimeout, :simultaneous)");
+        query.bindValue(":combo", combo);
+        query.bindValue(":cmds", cmds.join(":://::"));
+        query.bindValue(":cycle", cycle);
+        query.bindValue(":cycletimeout", cycletimeout);
+        query.bindValue(":simultaneous", simultaneous);
+        if(!query.exec())
+            qWarning() << "SQL error:" << query.lastError().text();
+        query.clear();
+
+    }
+
+    readDB();
 
 }
 
 void PQCShortcuts::resetToDefault() {
 
     setDefault();
+    setupFresh();
+    readDB();
+
+}
+
+void PQCShortcuts::setupFresh() {
+
+    qDebug() << "";
+
+    // at this point we can assume that the settings.db has already been copied
+
     readDB();
 
 }
