@@ -1,6 +1,6 @@
 /**************************************************************************
  **                                                                      **
- ** Copyright (C) 2011-2025 Lukas Spies                                  **
+ ** Copyright (C) 2011-2026 Lukas Spies                                  **
  ** Contact: https://photoqt.org                                         **
  **                                                                      **
  ** This file is part of PhotoQt.                                        **
@@ -20,7 +20,6 @@
  **                                                                      **
  **************************************************************************/
 
-#include <scripts/pqc_scriptsclipboard.h>
 #include <QMimeData>
 #include <QApplication>
 #include <QClipboard>
@@ -28,7 +27,7 @@
 #include <QTextDocumentFragment>
 #include <pqc_loadimage_archive.h>
 #include <pqc_configfiles.h>
-#include <scripts/pqc_scriptsother.h>
+#include <scripts/pqc_scriptsclipboard.h>
 #include <scripts/pqc_scriptsimages.h>
 
 PQCScriptsClipboard::PQCScriptsClipboard() {
@@ -36,8 +35,6 @@ PQCScriptsClipboard::PQCScriptsClipboard() {
     connect(clipboard, &QClipboard::dataChanged, this, &PQCScriptsClipboard::clipboardUpdated);
 }
 
-PQCScriptsClipboard::~PQCScriptsClipboard() {}
-
 bool PQCScriptsClipboard::areFilesInClipboard() {
 
     const QMimeData *mimeData = clipboard->mimeData();
