@@ -65,10 +65,6 @@
 #include <IL/il.h>
 #endif
 
-#ifdef PQMFREEIMAGE
-#include <FreeImage.h>
-#endif
-
 #ifdef PQMVIDEOMPV
 #include <pqc_mpvobject.h>
 #endif
@@ -151,10 +147,6 @@ QString PQCScriptsConfig::getConfigInfo(bool formatHTML) {
     txt += QString(" - %1GraphicsMagick%2: %3%4").arg(bold1, bold2, MagickLibVersionText, nl);
 #endif
 
-#ifdef PQMFREEIMAGE
-    txt += QString(" - %1FreeImage%2: %3.%4%5").arg(bold1, bold2).arg(FREEIMAGE_MAJOR_VERSION).arg(FREEIMAGE_MINOR_VERSION).arg(nl);
-#endif
-
 #ifdef PQMDEVIL
     txt += QString(" - %1DevIL%2: %3%4").arg(bold1, bold2).arg(IL_VERSION).arg(nl);
 #endif
@@ -520,13 +512,6 @@ bool PQCScriptsConfig::isDevILSupportEnabled() {
     return false;
 }
 
-bool PQCScriptsConfig::isFreeImageSupportEnabled() {
-#ifdef PQMFREEIMAGE
-    return true;
-#endif
-    return false;
-}
-
 bool PQCScriptsConfig::isPDFSupportEnabled() {
 #if defined PQMPOPPLER||PQMQTPDF
     return true;
@@ -611,6 +596,13 @@ bool PQCScriptsConfig::isICUSupportEnabled() {
     return true;
 }
 
+bool PQCScriptsConfig::isJasperWorkaroundsEnabled() {
+#ifdef PQMJASPERWORKAROUNDS
+    return true;
+#endif
+    return false;
+}
+
 void PQCScriptsConfig::callStartupSetupFresh() {
 
 #ifndef PQMTESTING
