@@ -68,10 +68,16 @@
 #include <exiv2/exiv2.hpp>
 #endif
 
-#ifdef PQMZXING
+#ifdef PQMZXINGQT
+#include <ZXing/ZXingQt.h>
+#elif defined(PQMZXING)
+#if __has_include(<ZXing/WriteBarcode.h>)
+#include <ZXing/ZXingCpp.h>
+#else
 #include <ZXing/ReadBarcode.h>
 #include <ZXing/ZXVersion.h>
 #endif
+#endif
 
 #if defined(PQMIMAGEMAGICK) || defined(PQMGRAPHICSMAGICK)
 #include <Magick++/Image.h>
@@ -97,7 +103,6 @@ PQCScriptsImages::PQCScriptsImages() {
 
     // lcms2CountFailedApplications = 0;
 
-    devicePixelRatioCached = 0;
     devicePixelRatioCachedWhen = 0;
 
 }
@@ -180,36 +185,68 @@ QString PQCScriptsImages::loadImageAndConvertToBase64(QString filename) {
 
 }
 
-void PQCScriptsImages::listArchiveContent(QString path, bool insideFilenameOnly) {
+void PQCScriptsImages::listArchiveContent(QString path) {
 
     qDebug() << "args: path =" << path;
-    qDebug() << "args: insideFilenameOnly =" << insideFilenameOnly;
 
     if(path.contains("::ARC::"))
         path = path.split("::ARC::").at(1);
 
+    const bool limitArchiveFileCount = PQCSettingsCPP::get().getFiletypesArchiveDontLoadMoreFilesThan();
+    const int limitArchiveFileCountNumber = PQCSettingsCPP::get().getFiletypesArchiveDontLoadMoreFilesThanCount();
+
     const QFileInfo info(path);
-    QString cacheKey = QString("%1::%2::%3::%4").arg(info.lastModified().toMSecsSinceEpoch()).arg(path, PQCSettingsCPP::get().getImageviewSortImagesAscending()).arg(insideFilenameOnly);
+    QString cacheKey = QString("%1::%2::%3::%4").arg(info.lastModified().toMSecsSinceEpoch())
+                                                .arg(path)
+                                                .arg(PQCSettingsCPP::get().getImageviewSortImagesAscending())
+                                                .arg(limitArchiveFileCount ? limitArchiveFileCountNumber : -1);
 
     if(archiveContentCache.contains(cacheKey)) {
+        qDebug() << "Found cached content, using that.";
         Q_EMIT haveArchiveContentFor(path, archiveContentCache[cacheKey]);
         return;
     }
 
+    if(inProcesOfLoadingTheseArchives.contains(cacheKey)) {
+        qDebug() << "Archive is currently being loaded. Waiting...";
+        QTimer::singleShot(500, [=]() { listArchiveContent(path); } );
+        return;
+    }
+
+    inProcesOfLoadingTheseArchives.append(cacheKey);
+
     QFuture<void> f = QtConcurrent::run([=]() {
-        Q_EMIT haveArchiveContentFor(path, PQCScriptsImages::listArchiveContentWithoutThread(path, cacheKey, insideFilenameOnly));
+        const QStringList ret = PQCScriptsImages::listArchiveContentWithoutThread(path, cacheKey);
+        Q_EMIT haveArchiveContentFor(path, ret);
+        inProcesOfLoadingTheseArchives.removeAt(inProcesOfLoadingTheseArchives.indexOf(cacheKey));
     });
 
 }
 
-QStringList PQCScriptsImages::listArchiveContentWithoutThread(QString path, QString cacheKey, bool insideFilenameOnly) {
+QStringList PQCScriptsImages::listArchiveContentWithoutThread(QString path, QString cacheKey) {
+
+    qDebug() << "args: path =" << path;
+    qDebug() << "args: cacheKey =" << cacheKey;
 
     QStringList ret;
 
+    const bool limitArchiveFileCount = PQCSettingsCPP::get().getFiletypesArchiveDontLoadMoreFilesThan();
+    const int limitArchiveFileCountNumber = PQCSettingsCPP::get().getFiletypesArchiveDontLoadMoreFilesThanCount();
+
     const QFileInfo info(path);
 
     if(cacheKey == "") {
-        cacheKey = QString("%1::%2::%3::%4").arg(info.lastModified().toMSecsSinceEpoch()).arg(path, PQCSettingsCPP::get().getImageviewSortImagesAscending()).arg(insideFilenameOnly);
+        cacheKey = QString("%1::%2::%3::%4").arg(info.lastModified().toMSecsSinceEpoch())
+                                            .arg(path)
+                                            .arg(PQCSettingsCPP::get().getImageviewSortImagesAscending())
+                                            .arg(limitArchiveFileCount ? limitArchiveFileCountNumber : -1);
+
+        qDebug() << "Constructed cacheKey =" << cacheKey;
+    }
+
+    if(archiveContentCache.contains(cacheKey)) {
+        qDebug() << "Found cached content, using that.";
+        return archiveContentCache[cacheKey];
     }
 
 #ifndef Q_OS_WIN
@@ -238,16 +275,13 @@ QStringList PQCScriptsImages::listArchiveContentWithoutThread(QString path, QStr
 
                 allfiles.sort();
 
-                if(insideFilenameOnly) {
-                    for(const QString &f : std::as_const(allfiles)) {
-                        if(PQCImageFormats::get().getEnabledFormats().contains(QFileInfo(f).suffix().toLower()))
-                            ret.append(f);
-                    }
-                } else {
-                    for(const QString &f : std::as_const(allfiles)) {
-                        if(PQCImageFormats::get().getEnabledFormats().contains(QFileInfo(f).suffix().toLower()))
-                            ret.append(QString("%1::ARC::%2").arg(f, path));
-                    }
+                // limit how many files to load
+                if(limitArchiveFileCount)
+                    allfiles = allfiles.mid(0, limitArchiveFileCountNumber);
+
+                for(const QString &f : std::as_const(allfiles)) {
+                    if(!isArchive(f, true) && PQCImageFormats::get().getEnabledFormats().contains(QFileInfo(f).suffix().toLower()))
+                        ret.append(f);
                 }
 
             }
@@ -285,31 +319,34 @@ QStringList PQCScriptsImages::listArchiveContentWithoutThread(QString path, QStr
             return ret;
         }
 
+        int counter = 0;
+
         // Loop over entries in archive
         struct archive_entry *entry;
         QStringList allfiles;
         while(archive_read_next_header(a, &entry) == ARCHIVE_OK) {
 
+            ++counter;
+
             // Read the current file entry
             // We use the '_w' variant here, as otherwise on Windows this call causes a segfault when a file in an archive contains non-latin characters
             QString filenameinside = QString::fromWCharArray(archive_entry_pathname_w(entry));
 
             // If supported file format, append to temporary list
             const QFileInfo info(filenameinside);
-            if(PQCImageFormats::get().getEnabledFormats().contains(info.suffix().toLower()) || PQCImageFormats::get().getEnabledFormats().contains(info.completeSuffix().toLower()))
+            if(!isArchive(filenameinside, true) && (PQCImageFormats::get().getEnabledFormats().contains(info.suffix().toLower()) || PQCImageFormats::get().getEnabledFormats().contains(info.completeSuffix().toLower())))
                 allfiles.append(filenameinside);
 
+            // limit how many files to load
+            if(limitArchiveFileCount && counter > limitArchiveFileCountNumber)
+                break;
+
         }
 
         // Sort the temporary list and add to global list
         allfiles.sort();
 
-        if(insideFilenameOnly) {
-            ret = allfiles;
-        } else {
-            for(const QString &f : std::as_const(allfiles))
-                ret.append(QString("%1::ARC::%2").arg(f, path));
-        }
+        ret = allfiles;
 
         // Close archive
         r = archive_read_free(a);
@@ -334,10 +371,10 @@ QStringList PQCScriptsImages::listArchiveContentWithoutThread(QString path, QStr
     else
         std::sort(ret.begin(), ret.end(), [&collator](const QString &file1, const QString &file2) { return collator.compare(file2, file1) < 0; });
 
-{
-    QMutexLocker locker(&archiveMutex);
-    archiveContentCache.insert(cacheKey, ret);
-}
+    {
+        QMutexLocker locker(&archiveMutex);
+        archiveContentCache.insert(cacheKey, ret);
+    }
 
     return ret;
 
@@ -444,9 +481,12 @@ bool PQCScriptsImages::isPDFDocument(QString path) {
 
 }
 
-bool PQCScriptsImages::isArchive(QString path) {
+bool PQCScriptsImages::isArchive(QString path, bool silent) {
 
-    qDebug() << "args: path =" << path;
+    // each entry in an archive is checked for whether it is an archive or not
+    // for archives with many files, this generates a LOT of output
+    // thus for that check we set the 'silent' flat
+    if(!silent) qDebug() << "args: path =" << path;
 
     if(PQCImageFormats::get().getEnabledFormatsLibArchive().contains(QFileInfo(path).suffix().toLower()) ||
        PQCImageFormats::get().getEnabledFormatsLibArchive().contains(QFileInfo(path).completeSuffix().toLower()))
@@ -772,7 +812,24 @@ QVariantList PQCScriptsImages::getZXingData(QString path) {
 
     QVariantList ret;
 
-#ifdef PQMZXING
+#ifdef PQMZXINGQT
+
+    QSize origSize;
+    QImage img;
+    PQCLoadImage::get().load(path, QSize(-1,-1), origSize, img);
+
+    // Read from QImage
+    for (const auto& barcode : ZXingQt::ReadBarcodes(img)) {
+
+        QVariantList vals;
+        vals << barcode.text();
+        vals << barcode.position().topLeft();
+        vals << barcode.position().bottomRight()-barcode.position().topLeft();
+        ret << vals;
+
+    }
+
+#elif defined(PQMZXING)
 
     QSize origSize;
     QImage img;
@@ -782,7 +839,7 @@ QVariantList PQCScriptsImages::getZXingData(QString path) {
     switch (img.format()) {
         case QImage::Format_ARGB32:
         case QImage::Format_RGB32:
-#if ZXING_VERSION_MAJOR <=2 && ZXING_VERSION_MINOR <= 2
+#if ZXING_VERSION_MAJOR ==2 && ZXING_VERSION_MINOR <= 2
     #if Q_BYTE_ORDER == Q_LITTLE_ENDIAN
             frmt = ZXing::ImageFormat::BGRX;
     #else
@@ -801,7 +858,7 @@ QVariantList PQCScriptsImages::getZXingData(QString path) {
             break;
         case QImage::Format_RGBX8888:
         case QImage::Format_RGBA8888:
-#if ZXING_VERSION_MAJOR <=2 && ZXING_VERSION_MINOR <= 2
+#if ZXING_VERSION_MAJOR ==2 && ZXING_VERSION_MINOR <= 2
             frmt = ZXing::ImageFormat::RGBX;
 #else
             frmt = ZXing::ImageFormat::RGBA;
@@ -815,51 +872,28 @@ QVariantList PQCScriptsImages::getZXingData(QString path) {
             frmt = ZXing::ImageFormat::Lum;
     }
 
-#if ZXING_VERSION_MAJOR == 1 && ZXING_VERSION_MINOR <= 2
-
-    // Read any bar code
-    const ZXing::DecodeHints hints = ZXing::DecodeHints().setFormats(ZXing::BarcodeFormat::Any);
-    const ZXing::Result r = ZXing::ReadBarcode({img.bits(), img.width(), img.height(), ZXing::ImageFormat::Lum}, hints);
-
-#elif (ZXING_VERSION_MAJOR == 2 && ZXING_VERSION_MINOR <= 1) || ZXING_VERSION_MAJOR == 1
+#if (ZXING_VERSION_MAJOR == 2 && ZXING_VERSION_MINOR <= 1)
 
     // Read all bar codes
-    const ZXing::DecodeHints hints = ZXing::DecodeHints().setFormats(ZXing::BarcodeFormat::Any);
-    const std::vector<ZXing::Result> results = ZXing::ReadBarcodes({img.bits(), img.width(), img.height(), ZXing::ImageFormat::Lum}, hints);
+    const auto results = ZXing::ReadBarcodes({img.bits(), img.width(), img.height(), frmt, static_cast<int>(img.bytesPerLine())});
 
 #else
 
     // Read all bar codes
-    auto hints = ZXing::ReaderOptions().setFormats(ZXing::BarcodeFormat::Any)
-                                                             .setTryHarder(true)
-                                                             .setTryInvert(true)
-                                                             .setTextMode(ZXing::TextMode::HRI)
-                                                             .setMaxNumberOfSymbols(10);
-    auto results = ZXing::ReadBarcodes({img.bits(), img.width(), img.height(), frmt, static_cast<int>(img.bytesPerLine())}, hints);
+    auto options = ZXing::ReaderOptions().setMaxNumberOfSymbols(10);
+    auto results = ZXing::ReadBarcodes({img.bits(), img.width(), img.height(), frmt, static_cast<int>(img.bytesPerLine())}, options);
 
 #endif
 
     /******************************/
     // process and store results
 
-#if ZXING_VERSION_MAJOR == 1 && ZXING_VERSION_MINOR <= 2
-
-    if(r.format() != ZXing::BarcodeFormat::None) {
-
-#else // ZXing 1.3 and up
-
     for(const auto& r : results) {
 
-#endif
-
         QVariantList vals;
-#if ZXING_VERSION_MAJOR == 1 && ZXING_VERSION_MINOR <= 4
-        vals << QString::fromStdWString(r.text());
-#else
         vals << QString::fromStdString(r.text());
-#endif
         vals << QPoint(r.position().topLeft().x, r.position().topLeft().y);
-        vals << QSize(r.position().bottomRight().x-r.position().topLeft().x, r.position().bottomRight().y-r.position().topLeft().y);
+        vals << QPoint(r.position().bottomRight().x-r.position().topLeft().x, r.position().bottomRight().y-r.position().topLeft().y);
         ret << vals;
 
     }
@@ -1226,7 +1260,7 @@ void PQCScriptsImages::removeThumbnailFor(QString path) {
 
 }
 
-double PQCScriptsImages::getPixelDensity() {
+double PQCScriptsImages::getPixelDensity(QString modelName) {
 
 #ifndef Q_OS_WIN
 
@@ -1234,6 +1268,8 @@ double PQCScriptsImages::getPixelDensity() {
     // Fractional scaling factors are currently (Qt 6.8.1) reported as full integers by QScreen::devicePixelRatio()
     // The same issue occurs in wayland-info (from wayland-utils 1.2.0) with the reported scale factor there
     // However, we can try to calculate the right scaling factor from the logical and physical dimensions reported by wayland-info
+    // Using the modelId of the current screen we can get the exact factor as floating point.
+    // It is HIGHLY RECOMMENDED to enable this part of the code if there is any chance this instance will be run on wayland.
 
     // If we are on wayland...
     if(qApp->platformName() == "wayland") {
@@ -1244,16 +1280,20 @@ double PQCScriptsImages::getPixelDensity() {
         const int timeout = 60*5;
 #endif
 
+#ifndef PQMWAYLANDSPECIFIC
+        modelName = "_all_";
+#endif
+
         // we cache a once calculated value for 5 or 1 minutes
         if(QDateTime::currentSecsSinceEpoch()-devicePixelRatioCachedWhen < timeout) {
-            return devicePixelRatioCached;
+            return devicePixelRatioCached.value(modelName, 1.0).toDouble();
         }
 
 #ifdef PQMWAYLANDSPECIFIC
 
         devicePixelRatioCached = PQCWayland::getDevicePixelRatio();
         devicePixelRatioCachedWhen = QDateTime::currentSecsSinceEpoch();
-        return devicePixelRatioCached;
+        return devicePixelRatioCached.value(modelName, 1.0).toDouble();
 
 #else
 
@@ -1357,14 +1397,14 @@ double PQCScriptsImages::getPixelDensity() {
             // Found single ratio across all screens
             if(useRatio > 0) {
 
-                devicePixelRatioCached = useRatio;
+                devicePixelRatioCached.insert("_all_", useRatio);
                 devicePixelRatioCachedWhen = QDateTime::currentSecsSinceEpoch();
                 return useRatio;
 
             // if error occurred, then we effectively disable this feature
             } else {
 
-                devicePixelRatioCached = 1;
+                devicePixelRatioCached.insert("_all_", 1);
                 devicePixelRatioCachedWhen = QDateTime::currentSecsSinceEpoch();
                 return 1;
 
